/*
* This file is part of Converseen, an open-source batch image converter
* and resizer.
*
* (C) Faster 2010
*
* This program is free software; you can redistribute it and/or modify
* it under the terms of the GNU General Public License as published by
* the Free Software Foundation; either version 2 of the License, or
* (at your option) any later version.
*
* This program is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
* GNU General Public License for more details.
* GNU General Public License for more details.
*
* You should have received a copy of the GNU General Public License
* along with this program; if not, write to the Free Software
* Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*
* Contact e-mail: Faster <faster3ck@gmail.com>
*
*/

#include <QMessageBox>
#include <QInputDialog>
#include <QFileInfo>
#include "converter.h"

Converter::Converter()
{
    zoom = false;

    dlgStatus = new DialogConversionStatus;
    dlgStatus->show();
}
Converter::~Converter()
{

}
//
bool Converter::convert(QString fileName, QString format, int quality, QString dest)
{
    Image my_image;
    QFileInfo fi(fileName);
    bool converted;

    QString status = tr("Converted!");
    if (zoom)
        status = tr("Converted and processed!");

    QString out = QString("%1/%2.%3").arg(dest).arg(fi.baseName()).arg(format);

    dlgStatus->counter(true);
    try {
        my_image.read(fileName.toStdString());

        // FIXME: toglimi:
        //Geometry geo = "60x40!";
        //geo.aspect(true);

        //my_image.resize("60x40!");
    //my_image.resize();


        if (zoom) {
            Image my_image_tmp = resize(my_image);
            my_image = my_image_tmp;
        }
        if (b_density) {
            Image my_image_tmp = changeDensity(my_image);
            my_image = my_image_tmp;
        }

        converted = writeImage(my_image, format, quality, out);
    }
    catch (Error& my_error) {
        converted = false;

        dlgStatus->counter(false);
        status = tr("Error: %1").arg(QString::fromStdString(my_error.what()));

        QMessageBox::critical(0, tr("Error!"),
                              tr("An error is occurred in opening %1: %2. It won't be processed!")
                              .arg(fi.baseName())
                              .arg(QString::fromStdString(my_error.what())));
    }




    dlgStatus->conversionStatus(fileName, status);



    return converted;
}

void Converter::setResize(QString resizingStr)
{
    resizingString = resizingStr;

    zoom = true;
}

void Converter::setDensity(QString densityStr)
{
    densityString = densityStr;

    b_density = true;
}

Image Converter::resize(Image &my_image)
{
    zoom = false; /* auto-reset resize mode */

    QString n_geo = QString(resizingString);/*n_geo.toStdString()*/
    my_image.resize(n_geo.toStdString());

    return my_image;
}

Image Converter::changeDensity(Image &my_image)
{
    b_density = false;

    QString n_den = QString(densityString);
    my_image.density(n_den.toStdString());

    return my_image;
}

//
bool Converter::writeImage(Image &my_image, QString format, int quality, QString out)
{
    my_image.magick(format.toStdString());
    //my_image.density("72x72");

    bool converted = false;

    if (quality != -1)
        my_image.quality(quality);

    try {
        if (renaming)   // rinomina
            my_image.write(renameFileName(out).toStdString());
        else
            if (!overwriting)   // modalità sovrascittura
                my_image.write(overwrite(out).toStdString());
            else
                my_image.write(out.toStdString());  // scrittura normale

        converted = true;
    }
    catch (Error& my_error) {
        converted = false;
    }

    return converted;
}

QString Converter::overwrite(QString out)
{
    QString newName;
    QString text;
    QFileInfo fi(out);

    bool ok;

    if (fi.exists()) {
        text = QInputDialog::getText(0, tr("Suggest a new name!"),
                                     tr("New name:"), QLineEdit::Normal,
                                     fi.baseName(), &ok);

        if (ok)
            newName = text;
        if (text.isEmpty() || !ok)
            newName = tr("%1/copy_%2.%3").arg(fi.path()).arg(newName).arg(fi.suffix());

        return QString("%1/%2.%3").arg(fi.path()).arg(newName).arg(fi.suffix());
    }
    else
        return out;
}

void Converter::setOverwrite(bool overwrite)
{
    overwriting = overwrite;
}

void Converter::setRenameMode(bool rename)
{
    renaming = rename;
}

void Converter::setRenamingString(QString renamingString)
{
    renamingLine = renamingString;
}

QString Converter::renameFileName(QString oldFileName)
{
    QString t_renamingString = renamingLine;

    QFileInfo fi(oldFileName);
    QString newFileName = QString("%1.%2")
                          .arg(t_renamingString.replace("#", fi.baseName()))
                          .arg(fi.suffix());

    return QString("%1/%2").arg(fi.path()).arg(newFileName);
}
