/*
* This file is part of Converseen, an open-source batch image converter
* and resizer.
*
* (C) Faster 2010
*
* This program is free software; you can redistribute it and/or modify
* it under the terms of the GNU General Public License as published by
* the Free Software Foundation; either version 2 of the License, or
* (at your option) any later version.
*
* This program is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
* GNU General Public License for more details.
* GNU General Public License for more details.
*
* You should have received a copy of the GNU General Public License
* along with this program; if not, write to the Free Software
* Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*
* Contact e-mail: Faster <faster3ck@gmail.com>
*
*/

#include <string>
#include <iostream>
#include "mainwindowimpl.h"
#include "dialogoptions.h"
#include "dialoginfo.h"
#define INIFILENAME ".converseen.conf"

using namespace Magick;
using namespace std;

MainWindowImpl::MainWindowImpl( QWidget * parent, Qt::WFlags f) 
        : QMainWindow(parent, f)
{
    setupUi(this);

    connect(pushOpen, SIGNAL(clicked()), this, SLOT(openFiles()));
    connect(buttonAdd, SIGNAL(clicked()), this, SLOT(addFiles()));
    connect(buttonConvert, SIGNAL(clicked()), this, SLOT(elabora()));
    connect(bntSelDir, SIGNAL(clicked()), this, SLOT(openOutDirectory()));
    connect(checkSameDir, SIGNAL(stateChanged(int)), this, SLOT(setCurrentDirectory()));
    connect(pushRemove, SIGNAL(clicked()), this, SLOT(removeItems()));
    connect(pushRemoveAll, SIGNAL(clicked()), this, SLOT(removeAllItems()));
    connect(btnFormatOptions, SIGNAL(clicked()), this, SLOT(setQuality()));
    connect(treeWidget, SIGNAL(itemSelectionChanged()), this, SLOT(onItemSelection()));

    connect(spin_geoWidth, SIGNAL(valueChanged(double)), this, SLOT(relativeSizeW(double)));
    connect(spin_geoHeight, SIGNAL(valueChanged(double)), this, SLOT(relativeSizeH(double)));

    connect(comboResizeValues, SIGNAL(currentIndexChanged(QString)), this, SLOT(selectGeometryUnit(QString)));

    connect(checkRename, SIGNAL(stateChanged(int)), this, SLOT(enableRenameLine()));
    connect(checkShowPreview, SIGNAL(stateChanged(int)), this, SLOT(enableShowPreview()));

    connect(pushReset, SIGNAL(clicked()), this, SLOT(on_pushResetClick()));


    createActions();
    setupMenu();
    createContextMenu();

    loadFormats();
    loadOptions();

    comboResizeValues->addItems((QStringList() << "%" << "px"));
    resetDisplays();

    //groupDimensions->setEnabled(false);

    adjustSize();
    dockWidget->adjustSize();
}
//
void MainWindowImpl::createActions()
{
    /* "File" actions*/
    actionOpenFiles = new QAction(tr("Open images to convert"), this);
    actionOpenFiles->setShortcut(tr("Ctrl+O"));
    connect(actionOpenFiles, SIGNAL(triggered()), this, SLOT(openFiles()));

    actionAddFiles = new QAction(tr("Add other images to convert"), this);
    actionAddFiles->setShortcut(tr("Ctrl+Alt+O"));
    connect(actionAddFiles, SIGNAL(triggered()), this, SLOT(addFiles()));

    actionShowOptions = new QAction(tr("Settings"), this);
    //actionShowOptions->setShortcut(tr("Ctrl+Alt+A"));
    connect(actionShowOptions, SIGNAL(triggered()), this, SLOT(editSettings()));

    actionClose = new QAction(tr("&Exit"), this);
    actionClose->setShortcut(tr("Ctrl+Q"));
    connect(actionClose, SIGNAL(triggered()), this, SLOT(close()));

    /* "Edit" actions */
    actionCheckItems = new QAction(tr("&Check Selected Items"), this);
    //actionCheckItems->setShortcut(tr("Ctrl+A"));
    connect(actionCheckItems, SIGNAL(triggered()), this, SLOT(checkItems()));

    actionCheckAllItems = new QAction(tr("&Check All Items"), this);
    actionCheckAllItems->setShortcut(tr("Ctrl+A"));
    connect(actionCheckAllItems, SIGNAL(triggered()), this, SLOT(checkAllItems()));

    actionUncheckItems = new QAction(tr("&Uncheck Selected Items"), this);
    //actionUncheckItems->setShortcut(tr("Alt+S"));
    connect(actionUncheckItems, SIGNAL(triggered()), this, SLOT(uncheckItems()));

    actionUncheckAllItems = new QAction(tr("&Uncheck All Items"), this);
    actionUncheckAllItems->setShortcut(tr("Ctrl+Shift+A"));
    connect(actionUncheckAllItems, SIGNAL(triggered()), this, SLOT(uncheckAllItems()));

    actionRemoveItems = new QAction(tr("&Remove Selected Items"), this);
    actionRemoveItems->setShortcut(Qt::Key_Delete);
    connect(actionRemoveItems, SIGNAL(triggered()), this, SLOT(removeItems()));

    actionRemoveAllItems = new QAction(tr("&Remove All Items"), this);
    //actionRemoveAllItems->setShortcut(tr("Ctrl+B"));
    connect(actionRemoveAllItems, SIGNAL(triggered()), this, SLOT(removeAllItems()));

    connect(pushCheck, SIGNAL(clicked()), this, SLOT(checkItems()));
    connect(pushCheckAll, SIGNAL(clicked()), this, SLOT(checkAllItems()));

    /* "Actions" actions */
    actionConvert = new QAction(tr("&Convert images"), this);
    actionConvert->setShortcut(tr("F5"));
    connect(actionConvert, SIGNAL(triggered()), this, SLOT(elabora()));

    actionInfo = new QAction(tr("&About..."), this);
    actionInfo->setShortcut(tr("F1"));
    connect(actionInfo, SIGNAL(triggered()), this, SLOT(about()));
}
//
void MainWindowImpl::setupMenu()
{
    menu_File->addAction(actionOpenFiles);
    menu_File->addAction(actionAddFiles);
    menu_File->addSeparator();
    menu_File->addAction(actionShowOptions);
    menu_File->addSeparator();
    menu_File->addAction(actionClose);

    menu_Edit->addAction(actionRemoveItems);
    menu_Edit->addAction(actionRemoveAllItems);
    menu_Edit->addSeparator();
    menu_Edit->addAction(actionCheckItems);
    menu_Edit->addAction(actionCheckAllItems);
    menu_Edit->addAction(actionUncheckItems);
    menu_Edit->addAction(actionUncheckAllItems);

    menu_Actions->addAction(actionConvert);

    menu_About->addAction(actionInfo);
}
//
void MainWindowImpl::createContextMenu()
{
    treeWidget->setContextMenuPolicy(Qt::ActionsContextMenu);
    treeWidget->addAction(actionCheckItems);
    treeWidget->addAction(actionCheckAllItems);
    treeWidget->addAction(actionUncheckItems);
    treeWidget->addAction(actionUncheckAllItems);
    treeWidget->addAction(actionRemoveItems);
    treeWidget->addAction(actionRemoveAllItems);
}
//
void MainWindowImpl::openFiles()
{
    iAList.clear();
    addFiles();
}
//
void MainWindowImpl::addFiles()
{
    QString path = QDir::homePath();
    if (settings->contains("General/Last Opened"))
        path = settings->value("General/Last Opened").toString();

    QStringList fileNames = QFileDialog::getOpenFileNames(this,
                                                          tr("Open Image"), path,
                                                          readableFiltersString);

    if (!fileNames.isEmpty()) {
        treeWidget->clear();

        QFileInfo fi(fileNames.at(0));
        settings->setValue("General/Last Opened", fi.path());

        for (int i = 0; i < fileNames.count(); i++) {
            QFileInfo fi(fileNames.at(i).toLocal8Bit());
            ImageAttributes iA;

            /* Controlla i doppioni! */
            if (!checkDuplicates(fileNames.at(i).toLocal8Bit())) {

                iA.completeFileName = fileNames.at(i).toLocal8Bit();
                iA.fileName = fi.fileName();
                iA.suffix = fi.suffix();
                iA.size = fi.size();
                iA.path = fi.path();
                iAList << iA;   // aggiunge

                //qDebug() << fi.fileName();

            }
        }
        fillTreeView();
    }
}
//
bool MainWindowImpl::checkDuplicates(QString currentFileName)
{
    bool exists = false;
    for (int i = 0; i < iAList.count(); i++) {
        //qDebug() << currentFileName << " : " << iAList.at(i).completeFileName;
        if (iAList.at(i).completeFileName == currentFileName) {

            //qDebug() << iAList.at(i).completeFileName << " già esiste!";
            statusBar()->showMessage(tr("Image %1 is currently used!").arg(currentFileName), 5000);
            exists = true;
        }
    }
    return exists;
}
//
void MainWindowImpl::fillTreeView()
{
    for (int i = 0; i < iAList.count(); i++) {
        QTreeWidgetItem *item = new QTreeWidgetItem(treeWidget);
        item->setCheckState(0, Qt::Unchecked);
        item->setText(2, iAList.at(i).fileName);
        item->setText(3, iAList.at(i).suffix);
        item->setText(4, simplifyFileSize(iAList.at(i).size));
        //
        item->setText(5, iAList.at(i).path);
    }
}
//
void MainWindowImpl::elabora()
{
    if (!lineDirectory->text().isEmpty()) {
        if (!iAList.isEmpty()) {
            if (areThereImagesChecked())
                convert();
            else
                QMessageBox::warning(0, tr("Warning"),
                                 tr("No image checked!"));
        }
        else
            QMessageBox::warning(0, tr("Warning"),
                                 tr("No images to convert!"));
    }
    else
        QMessageBox::warning(0, tr("Warning"),
                                 tr("Set an output directory!"));
}
//
void MainWindowImpl::convert()
{
    statusBar()->showMessage(tr("Processing..."));
    QTreeWidgetItemIterator it(treeWidget);
    Converter *convert = new Converter;

    if (!checkRename->isChecked()) {
        convert->setOverwrite(false);
        convert->setRenameMode(false);
    }
    else {
        convert->setOverwrite(overwriteMode());
        convert->setRenameMode(true);
        convert->setRenamingString(lineRename->text());
    }

    QApplication::setOverrideCursor(Qt::WaitCursor);

    for (int i = 0; i < iAList.count(); i++) {
        statusBar()->showMessage(tr("Please wait! Processing %1").arg(iAList.at(i).completeFileName));

        QString status;
        QString format = comboWFormats->currentText().split(" - ").at(0);
        QString destination = lineDirectory->text();

        if (checkSameDir->isChecked())
            destination = iAList.at(i).path;

        int quality = -1;

        if ((format == "JPG") || (format == "JPEG") || (format == "MPEG") || (format == "MPG")) {
           // qDebug() << "Sto usando un livello di compressione 100 = " << jpgQuality;
            quality = jpgQuality;
        }

        if ((format == "PNG") || (format == "MNG")) {
            //qDebug() << "Sto usando un livello di compressione 9 = " << pngQuality;
            quality = pngQuality;
        }

        if ((*it)->checkState(0)) {
            //qDebug() << "Sto convertendo:" << iAList.at(i).completeFileName;

            /* Change image size */
            if (groupDimensions->isChecked()) {
                QString aspectRatio = "!";

                if (checkRelative->isChecked())
                    aspectRatio = "";

                // "%1 x %2 % !"

                QString resizingString;
                if (comboResizeValues->currentText() == "px")
                    resizingString = QString("%1x%2%3")
                                             .arg(new_img_width)
                                             .arg(new_img_height)
                                             .arg(aspectRatio);
                if (comboResizeValues->currentText() == "%")
                    resizingString = QString("%1x%2%")
                                             .arg(spin_geoWidth->value())
                                             .arg(spin_geoHeight->value());

                //qDebug() << "geometry arg = " << resizingString;

                convert->setResize(resizingString);
            }

            /* Change image density */
            if ((groupDimensions->isChecked()) && ((m_xResolution != spin_resX->value()) || (m_yResolution != spin_resY->value()))) {
                //qDebug() << "Risoluzione cambiata";
                QString densStr = QString("%1x%2")
                                  .arg(spin_resX->value())
                                  .arg(spin_resY->value());

                convert->setDensity(densStr);
            }

            if (convert->convert(iAList.at(i).completeFileName, format.toLower(), quality, destination))
                status = "ok";
            else
                status = "error";

            (*it)->setText(1, status);
        }
        ++it;
    }

    QApplication::restoreOverrideCursor();
    statusBar()->showMessage(tr("Processing finished!"), 5000);
    settings->setValue("General/Last Write Format", comboWFormats->currentIndex());

    delete convert;
}
//
void MainWindowImpl::loadFormats()
{
    list<CoderInfo> coderList;
    coderInfoList(&coderList,
                  CoderInfo::TrueMatch,
                  CoderInfo::AnyMatch,
                  CoderInfo::AnyMatch);

    list<CoderInfo>::iterator entry = coderList.begin();
    QStringList writableFormats;
    QString readableExts;

    while(entry != coderList.end())
    {
        // TODO: Mettere una lista con tutti i formati!!!
        //qDebug() << QString::fromStdString(entry->name()) << ":" << QString::fromStdString(entry->description());

        if (entry->isReadable()) {
            readableFiltersString += QString(";;%3 [*.%1] (*.%1 *.%2 )")
            .arg(QString::fromStdString(entry->name()).toLower())   // Lower and upper filters for gnome compatibility (?)
            .arg(QString::fromStdString(entry->name()))
            .arg(QString::fromStdString(entry->description()));

            readableExts += QString("*.%1 *.%2 ")
                            .arg(QString::fromStdString(entry->name()).toLower())
                            .arg(QString::fromStdString(entry->name()));
        }

        if (entry->isWritable())
            writableFormats << QString("%1 - (%2)")
            .arg(QString::fromStdString(entry->name()))
            .arg(QString::fromStdString(entry->description()));

        entry ++;
    }
    readableFiltersString.prepend(tr("All Supported Formats (%1)").arg(readableExts));
    comboWFormats->addItems(writableFormats);
}
//
void MainWindowImpl::setCurrentDirectory()
{
    bool enabled;

    if (checkSameDir->isChecked())
        enabled = false;
    else
        enabled = true;

    lineDirectory->setEnabled(enabled);
    bntSelDir->setEnabled(enabled);
}
//
void MainWindowImpl::openOutDirectory()
{
    QString dir = QFileDialog::getExistingDirectory(this, tr("Open Directory"),
                                                    QDir::homePath(),
                                                    QFileDialog::ShowDirsOnly
                                                    | QFileDialog::DontResolveSymlinks);

    if (!dir.isNull()) {
        lineDirectory->setText(dir);
        settings->setValue("General/Save directory", lineDirectory->text());
    }
}
//
void MainWindowImpl::loadOptions()
{
    QString iniPath = QDir::homePath() + "/" + INIFILENAME;
    settings = new QSettings(iniPath, QSettings::IniFormat);

    if (!settings->contains("General/Save directory"))
        lineDirectory->setText(QDir::homePath());
    else
        lineDirectory->setText(settings->value("General/Save directory").toString());

    comboWFormats->setCurrentIndex(settings->value("General/Last Write Format").toInt());

    loadQuality();
}
//
void MainWindowImpl::setQuality()
{
    loadQuality();

    DialogQuality *dlg = new DialogQuality();
    dlg->setInitValues(jpgQuality, pngQuality);
    if (dlg->exec()) {
        jpgQuality = dlg->getJpegQuality();
        pngQuality = dlg->getPngQuality();

        settings->setValue("Quality/Jpeg quality", jpgQuality);
        settings->setValue("Quality/Png quality", pngQuality);
    }
}
//
void MainWindowImpl::loadQuality()
{
    if (settings->contains("Quality/Jpeg quality"))
        jpgQuality = settings->value("Quality/Jpeg quality").toInt();
    else
        jpgQuality = 85;

    if (settings->contains("Quality/Png quality"))
        pngQuality = settings->value("Quality/Png quality").toInt();
    else
        pngQuality = 7;
}
//
void MainWindowImpl::checkItems()
{
    QTreeWidgetItemIterator it(treeWidget);
    while (*it) {
        if ((*it)->isSelected())
            (*it)->setCheckState (0, Qt::Checked);
        ++it;
    }
}
//
void MainWindowImpl::checkAllItems()
{
    QTreeWidgetItemIterator it(treeWidget);
    while (*it) {
        (*it)->setCheckState (0, Qt::Checked);
        ++it;
    }
}
//
void MainWindowImpl::uncheckItems()
{
    QTreeWidgetItemIterator it(treeWidget);
    while (*it) {
        if ((*it)->isSelected())
            (*it)->setCheckState (0, Qt::Unchecked);
        ++it;
    }
}
//
void MainWindowImpl::uncheckAllItems()
{
    QTreeWidgetItemIterator it(treeWidget);
    while (*it) {
        (*it)->setCheckState (0, Qt::Unchecked);
        ++it;
    }
    //labelPreview->setText(tr("No preview!"));
}
//
void MainWindowImpl::removeItems()
{
    QTreeWidgetItemIterator it(treeWidget);
    int i = 0;

    while (*it) {
        if ((*it)->isSelected()) {
            iAList.removeAt(i);
            i--;
        }

        i++;
        it++;
    }
    treeWidget->clear();
    fillTreeView();

    resetDisplays();
}
//
void MainWindowImpl::removeAllItems()
{
    treeWidget->clear();
    iAList.clear();

    resetDisplays();
}
//
void MainWindowImpl::relativeSizeW(double value)
{
    if (checkRelative->isChecked()) {
        if (comboResizeValues->currentText() == "px") {
            double relative_H = ( ((double)img_height * value) / (double)img_width);
            spin_geoHeight->setValue((double)qRound(relative_H));
        }
    }

    if (comboResizeValues->currentText() == "%") {
        if (checkRelative->isChecked())
            spin_geoHeight->setValue(spin_geoWidth->value());
    }

    showNewImgsizePreview();
}

void MainWindowImpl::relativeSizeH(double value)
{
    if (checkRelative->isChecked()) {
        if (comboResizeValues->currentText() == "px") {
            double relative_V = ( ((double)img_width * value) / (double)img_height);
            spin_geoWidth->setValue((double)qRound(relative_V));
        }
    }
    if (comboResizeValues->currentText() == "%") {
        if (checkRelative->isChecked())
            spin_geoWidth->setValue(spin_geoHeight->value());
    }
    showNewImgsizePreview();
}

QImage* MainWindowImpl::toQImage(Image &image)
{
    // Fixme: magari mettere insieme alle altre in un load info
    // riempire info immagine

    QImage *newQImage = new QImage(image.columns(), image.rows(), QImage::Format_RGB32);

    // Fills img_widht and img_height:
    img_width = image.columns();
    img_height = image.rows();

    // Load img resolution:
    m_xResolution = image.xResolution();
    m_yResolution = image.yResolution();

    const Magick::PixelPacket *pixels;
    Magick::ColorRGB rgb;
    for (int y = 0; y < newQImage->height(); y++) {
        pixels = image.getConstPixels(0, y, newQImage->width(), 1);
        for (int x = 0; x < newQImage->width(); x++) {
            rgb = (*(pixels + x));
            newQImage->setPixel(x, y, QColor((int) (255 * rgb.red())
                                             , (int) (255 * rgb.green())
                                             , (int) (255 * rgb.blue())).rgb());
        }
    }
    return newQImage;
}
//
void MainWindowImpl::loadPreview(QString fileName)
{
    try {
        Image aMagickImage(fileName.toStdString());

        QImage *aQImage = toQImage(aMagickImage);

        if (checkShowPreview->isChecked()) {
            if ((aQImage->width() < 240) || (aQImage->height() < 190))
                labelPreview->setPixmap(QPixmap::fromImage(*aQImage));
            else
                labelPreview->setPixmap(QPixmap::fromImage(*aQImage).scaled(QSize(190, 190),
                                                  Qt::KeepAspectRatio,
                                                  Qt::SmoothTransformation));
        }
        else
            resetDisplays(); /* Resets preview,
                                sizes,
                             */

        delete aQImage;
    }
    catch (Error& my_error) {
        labelPreview->setText(tr("Sorry! Selected image is damaged!"));
    }
}
//
void MainWindowImpl::onItemSelection()
{
    showImageInformations();
    //groupDimensions->setEnabled(true);
    //selectGeometryUnit(comboResizeValues->currentText()); reset
}

void MainWindowImpl::on_pushResetClick()
{
    selectGeometryUnit(comboResizeValues->currentText());
    spin_resX->setValue(m_xResolution);
    spin_resY->setValue(m_yResolution);
}

void MainWindowImpl::showImageInformations()
{
    int index = treeWidget->currentIndex().row();
    loadPreview(iAList.at(index).completeFileName);

    labelType->setText(QString("<span style=\" font-size:8pt;\">%1</span>")
                       .arg(iAList.at(index).suffix));

    QString sSize = simplifyFileSize(iAList.at(index).size);
    labelFileSize->setText(QString("<span style=\" font-size:8pt;\">%1</span>")
                           .arg(sSize));

    label_ImageSize->setText(QString("<span style=\" font-size:8pt;\">%1 x %2 px</span>")
                             .arg(img_width)
                             .arg(img_height));

    label_ImageResolution->setText(QString("<span style=\" font-size:8pt;\">X = %1 Y = %2</span>")
                                   .arg(m_xResolution)
                                   .arg(m_yResolution));
}
//
void MainWindowImpl::editSettings()
{
    DialogOptions dlg;
    dlg.exec();
}
//
bool MainWindowImpl::overwriteMode()
{
    bool overwritingMode;

    if (settings->contains("Options/Overwrite mode"))
        overwritingMode = settings->value("Options/Overwrite mode").toBool();
    else
        overwritingMode = false;

    return overwritingMode;
}
//
QString MainWindowImpl::simplifyFileSize(qint64 size)
{
    QString sSize = "0";

    sSize = QString("%1 Bytes").arg(size);
    if (size > 1024)
        sSize = QString("%1 KiB").arg(QString::number( ((double)size / 1024), 'f', 1) );
    if (size / 1024 > 1024)
        sSize = QString("%1 MiB").arg(QString::number( ((double)size / 1024 / 1024), 'f', 1) );

    return sSize;
}
//
bool MainWindowImpl::areThereImagesChecked()
{
    QTreeWidgetItemIterator it(treeWidget);
    int i = 0;
    while (*it) {
        if ((*it)->checkState(0) == Qt::Checked)
            i++;
        ++it;
    }
    if (i > 0)
        return true;
    else
        return false;
}
//
void MainWindowImpl::about()
{
    DialogInfo dlg;
    dlg.exec();
}
//
void MainWindowImpl::enableRenameLine()
{
    if (checkRename->isChecked())
        lineRename->setEnabled(true);
    else
        lineRename->setEnabled(false);
}
//
void MainWindowImpl::enableShowPreview()
{
    if(treeWidget->selectedItems().count() > 0)
        onItemSelection();
    else
        labelPreview->setText(tr("No preview!"));
}
//
void MainWindowImpl::selectGeometryUnit(QString unit)
{
    if (unit == "px") {
        spin_geoWidth->setDecimals(0);
        spin_geoWidth->setSuffix(" px");
        spin_geoWidth->setValue((double)img_width);

        spin_geoHeight->setDecimals(0);
        spin_geoHeight->setSuffix(" px");
        spin_geoHeight->setValue((double)img_height);
    }
    if (unit == "%") {
        //spin_geoWidth->setDecimals(2);
        spin_geoWidth->setSuffix(" %");
        spin_geoWidth->setValue(100.00);

        //spin_geoHeight->setDecimals(2);
        spin_geoHeight->setSuffix(" %");
        spin_geoHeight->setValue(100.00);
    }
}
//
void MainWindowImpl::showNewImgsizePreview()
{
    if (comboResizeValues->currentText() == "%") {
        double new_width, new_height, round_new_width, round_new_height;

        new_width = (((double)img_width / 100) * (spin_geoWidth->value()));
        new_height = (((double)img_height / 100) * (spin_geoHeight->value()));

        round_new_width = qRound(new_width);
        round_new_height = qRound(new_height);


        labelPixelGeometry->setText(QString("<span style=\" font-size:8pt;\"><center>%1 x %2 pixels</center></span>")
                                    .arg(round_new_width)
                                    .arg(round_new_height));

        new_img_width = round_new_width;
        new_img_height = round_new_height;
    }
    if (comboResizeValues->currentText() == "px") {
        labelPixelGeometry->setText(QString("<span style=\" font-size:8pt;\"><center>%1 x %2 pixels</center></span>")
                                    .arg(spin_geoWidth->value())
                                    .arg(spin_geoHeight->value()));

        new_img_width = spin_geoWidth->value();
        new_img_height = spin_geoHeight->value();
    }
}
//
void MainWindowImpl::resetDisplays()
{
    labelPreview->setText(tr("No preview!"));

    img_width = 0;
    img_height = 0;

    new_img_width = 0;
    new_img_height = 0;

    m_xResolution = 0;
    m_yResolution = 0;

    spin_resX->setValue(m_xResolution);
    spin_resY->setValue(m_yResolution);

    if (comboResizeValues->currentText() == "%") {
        spin_geoWidth->setValue(100);
        spin_geoHeight->setValue(100);
    }
    if (comboResizeValues->currentText() == "px") {
        spin_geoWidth->setValue(1);
        spin_geoHeight->setValue(1);
    }

    labelType->setText(" - ");
    label_ImageSize->setText(" - ");
    labelFileSize->setText(" - ");
    label_ImageResolution->setText(" - ");

    labelPixelGeometry->setText("<span style=\" font-size:8pt;\"><center>0 x 0 pixels</center></span>");

    //if (iAList.isEmpty())
    //    groupDimensions->setEnabled(false);
}
