/*
* This file is part of Converseen, an open-source batch image converter
* and resizer.
*
* (C) Faster 2010
*
* This program is free software; you can redistribute it and/or modify
* it under the terms of the GNU General Public License as published by
* the Free Software Foundation; either version 2 of the License, or
* (at your option) any later version.
*
* This program is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
* GNU General Public License for more details.
* GNU General Public License for more details.
*
* You should have received a copy of the GNU General Public License
* along with this program; if not, write to the Free Software
* Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*
* Contact e-mail: Faster <faster3ck@gmail.com>
*
*/

#ifndef MAINWINDOWIMPL_H
#define MAINWINDOWIMPL_H
//
#include <QMainWindow>
#include <QtGui>
#include <QFileInfo>
#include <QList>
#include <QSettings>
#include "ui_mainwindow.h"
#include "converter.h"
#include "dialogquality.h"
//
class ImageAttributes
{
public:
    QString completeFileName, fileName, suffix, path, format;
    qint64 size;
};
//
class MainWindowImpl : public QMainWindow, public Ui::MainWindow
{
    Q_OBJECT
public:
    MainWindowImpl( QWidget * parent = 0, Qt::WFlags f = 0 );
private:
    void createActions();
    void setupMenu();
    void createContextMenu();
    bool checkDuplicates(QString currentFileName);
    void convert();
    void fillTreeView();
    void loadFormats();
    void loadOptions();
    void loadQuality();

    void deleteItems(int selectedItems);

    QImage *toQImage(Image &image);
    void loadPreview(QString fileName);
    void showImageInformations();   // quello che succede alla selezione dell'item.

    bool overwriteMode();
    QString simplifyFileSize(qint64 size);
    bool areThereImagesChecked();   // Verify if there are images checked
    void resetDisplays();

    QSettings *settings;

    QList<ImageAttributes> iAList;
    QString readableFiltersString;

    QAction *actionOpenFiles;
    QAction *actionAddFiles;
    QAction *actionShowOptions;
    QAction *actionClose;

    QAction *actionConvert;

    QAction *actionCheckItems;
    QAction *actionCheckAllItems;
    QAction *actionUncheckItems;
    QAction *actionUncheckAllItems;
    QAction *actionRemoveItems;
    QAction *actionRemoveAllItems;
    QAction *actionInfo;

    int jpgQuality;
    int pngQuality;
    int img_width,img_height;  /* vengono riempiti per convenienza solo quando un'immagine è selezionata.
                                  Riempire con dati su ImageAttributes potrebbe essere lento e non conveniente! */
    int new_img_width,new_img_height; /* Vengono riempiti con numeri che rappresentano i pixel dato che non capisco come
                                         si passa la corretta percentuale in virgola mobile a geometry*/
    int m_xResolution, m_yResolution;
private slots:
    void openFiles();
    void addFiles();
    void elabora();
    void setCurrentDirectory();
    void openOutDirectory();
    void checkItems();
    void checkAllItems();
    void uncheckItems();
    void uncheckAllItems();
    void removeItems();
    void removeAllItems();
    void setQuality();
    void selectGeometryUnit(QString unit);
    void relativeSizeW(double value);
    void relativeSizeH(double value);

    void onItemSelection();
    void editSettings();

    void about();

    void enableRenameLine();
    void enableShowPreview();

    void showNewImgsizePreview();

    void on_pushResetClick();
};
#endif // MAINWINDOWIMPL_H
