/*
* This file is part of Converseen, an open-source batch image converter
* and resizer.
*
* (C) Faster 2010
*
* This program is free software; you can redistribute it and/or modify
* it under the terms of the GNU General Public License as published by
* the Free Software Foundation; either version 2 of the License, or
* (at your option) any later version.
*
* This program is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
* GNU General Public License for more details.
* GNU General Public License for more details.
*
* You should have received a copy of the GNU General Public License
* along with this program; if not, write to the Free Software
* Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*
* Contact e-mail: Faster <faster3ck@gmail.com>
*
*/

#include <QDir>
#include "translator.h"
#include "whereiam.h"

QString shareDir;
QString language;

Translator::Translator()
{
    WhereIAm w;
    shareDir = w.shareDir();

    //qDebug() << "Share Dir" << shareDir;

    settings = new QSettings(QDir::homePath()+"/.converseen.conf", QSettings::IniFormat);
}
//
QTranslator *Translator::translation()
{
    QTranslator *transl = new QTranslator;
    QString translationFile = QString("%1/converseen/"+loadSettings()).arg(shareDir);
    transl->load(translationFile);

    return(transl);
}
//
QString Translator::loadSettings()  // Sarebbe meglio "loadCurrentTranslationName"
{
    QString language = "English";
    if (settings->contains("Options/language")) {
        language = settings->value("Options/language").value<QString>();
    }
    return(language);
}
//
void Translator::saveSettings(QString language)
{
    if (language != "English") {
        QString lang = language;

        settings->setValue("Options/language", lang);
    }
    else
        settings->setValue("Options/language", "English");

    //qDebug() << language;
}
//
QList<QPair<QString, QString> > Translator::loadTranslationFiles()
{
    language = tr("English");
    QTranslator transl;

    QDir trPath(QString("%1/converseen").arg(shareDir));
    QStringList fileNames = trPath.entryList(QStringList() << "*.qm", QDir::Files, QDir::Name);

    QList<QPair<QString, QString> > langsList;
    QPair<QString, QString> lang;

    for (int i = 0; i < fileNames.count(); i++) {
        lang.first = fileNames.at(i);

        transl.load(fileNames.at(i), QString("%1/converseen").arg(shareDir));
        lang.second = transl.translate("Translator", "English");

        langsList << lang;
    }
    return langsList;
}

QString Translator::currentLanguage()
{
    return language;
}
